
// acceleration.js
// Gets acceleration sensor data from web service and displays it
// as realtime plotted data in a canvas

let Server =
{
    url: ""
}

let AccelerometerData =
{
    lastId: 0
}

function getLatestAccelerometerData(axis_x, axis_y, axis_z)
{
    if (AccelerometerData.lastId === 0)
    {
        $.getJSON(Server.url,
        	{},
        function (data, status)
        {
            if (status === "success")
            {
                AccelerometerData.lastId = data.accelerationData.lastMeasurementId;

                // In order to be compatible with the Safari browser, we cannot just pass in
                // the datetime string into the Date() constructor. Instead, we much pass in
                // each datetime component as a parameter to the Date() constructor
                let dateComps = data.accelerationData.accelerationMeasurements[0].dateTime.split(/[^0-9]/);
                let dateTime = new Date(dateComps[0], dateComps[1] - 1, dateComps[2],
                        dateComps[3], dateComps[4], dateComps[5], dateComps[6]).getTime();

                let xValue = data.accelerationData.accelerationMeasurements[0].axis.X;
                let yValue = data.accelerationData.accelerationMeasurements[0].axis.Y;
                let zValue = data.accelerationData.accelerationMeasurements[0].axis.Z;

                axis_x.append(dateTime, xValue);
                axis_y.append(dateTime, yValue);
                axis_z.append(dateTime, zValue);
           }
        });
    }
    else // Send GET using last measured Id
    {
        $.getJSON(Server.url,
        	{lastMeasurementId: AccelerometerData.lastId},
        function (data, status)
        {
            if (status === "success")
            {
                AccelerometerData.lastId = data.accelerationData.lastMeasurementId;

                data.accelerationData.accelerationMeasurements.forEach(function(accelerationMeasurement)
                {
                    // In order to be compatible with the Safari browser, we cannot just pass in
                    // the datetime string into the Date() constructor. Instead, we much pass in
                    // each datetime component as a parameter to the Date() constructor
                    let dateComps = accelerationMeasurement.dateTime.split(/[^0-9]/);
                    let dateTime = new Date(dateComps[0], dateComps[1] - 1, dateComps[2],
                            dateComps[3], dateComps[4], dateComps[5], dateComps[6]).getTime();

                    let xValue = accelerationMeasurement.axis.X;
                    let yValue = accelerationMeasurement.axis.Y;
                    let zValue = accelerationMeasurement.axis.Z;

                    axis_x.append(dateTime, xValue);
                    axis_y.append(dateTime, yValue);
                    axis_z.append(dateTime, zValue);
                });
            }
        });
    }
}

function plotAccelerometerData()
{
    $.getJSON('js_get_server_name.php',
    function(data)
    {
        Server.url = "http:\/\/" + data.server_name + "/accelerometerservice/";
    });


    let x = new TimeSeries();
    let y = new TimeSeries();
    let z = new TimeSeries();

    setInterval(function()
    {
	    getLatestAccelerometerData(x, y, z);
    }, 1000);

    let smoothie = new SmoothieChart(
        {
            responsive: true,
            grid:
            { 
                strokeStyle: 'rgb(125, 0, 0)',
                fillStyle: 'rgb(60, 0, 0)',
                lineWidth: 1,
                millisPerLine: 250,
                verticalSections: 6
            },
            labels: { fillStyle:'rgb(255, 255, 0)' }
        });

    smoothie.addTimeSeries(x, { strokeStyle: 'rgb(0, 255, 0)', fillStyle: 'rgba(0, 255, 0, 0.3)', lineWidth: 3 });
    smoothie.addTimeSeries(y, { strokeStyle: 'rgb(255, 0, 255)', fillStyle: 'rgba(255, 0, 255, 0.3)', lineWidth: 3 });
    smoothie.addTimeSeries(z, { strokeStyle: 'rgb(0, 0, 255)', fillStyle: 'rgba(0, 0, 255, 0.3)', lineWidth: 3 });

    smoothie.streamTo(document.getElementById("acceleration_data_plot_canvas"), 1000);
}
